@@ -30,7 +30,7 @@ from mitosheet.user.db import get_user_field
 from mitosheet.user.location import is_in_google_colab, is_in_vs_code
 from mitosheet.user.schemas import (UJ_MITOSHEET_LAST_FIFTY_USAGES,
                                     UJ_RECEIVED_TOURS, UJ_USER_EMAIL)
-from mitosheet.user.utils import is_excel_import_enabled, is_pro
+from mitosheet.user.utils import is_excel_import_enabled, is_pro, is_running_test
 
 
 class MitoWidget(DOMWidget):
@@ -165,7 +165,7 @@ class MitoWidget(DOMWidget):
         # with the response (like an error), to get this response in-place!
         self.send({
             'event': 'response',
-            'id': event['id']
+            'id': event['id'],
         })
 
     def receive_message(self, widget: Any, content: Dict[str, Any], buffers: Any=None) -> bool:
@@ -199,14 +199,20 @@ class MitoWidget(DOMWidget):
                 # NOTE: since API calls are in a seperate thread, their start time and end
                 # time are not valid, and so we don't even log the start time to not be confusing
                 start_time = None
+
             
-            # NOTE: we don't need to case on log_event above because it always gets
-            # passed to this function, and thus is logged.
-            log_event_processed(event, self.steps_manager, start_time=start_time)
+            if event['event'] != 'api_call':
+                # NOTE: we don't need to case on log_event above because it always gets
+                # passed to this function, and thus is logged. We also don't log in the
+                # case of an API event as that is in a seperate thread and so takes care
+                # of it's logging seperately
+                log_event_processed(event, self.steps_manager, start_time=start_time)
 
             return True
         except MitoError as e:
-            
+            if is_running_test():
+                print(e)
+
             # Log processing this event failed
             log_event_processed(event, self.steps_manager, failed=True, mito_error=e, start_time=start_time)
 
@@ -233,6 +239,8 @@ class MitoWidget(DOMWidget):
             # Report it to the user, and then return
             self.send(response)
         except:
+            if is_running_test():
+                print(get_recent_traceback())
             # We log that processing failed, but have no edit error
             log_event_processed(event, self.steps_manager, failed=True, start_time=start_time)
             # Report it to the user, and then return
