@@ -59,7 +59,7 @@ def check_dataframes_equal(test_wrapper):
         df_name: df.copy(deep=True) for df, df_name in 
         zip(
             test_wrapper.mito_widget.steps_manager.original_args,
-            test_wrapper.mito_widget.steps_manager.steps[0].df_names
+            test_wrapper.mito_widget.steps_manager.steps_including_skipped[0].df_names
         )
     }
     final_dfs = {
@@ -132,15 +132,15 @@ class MitoWidgetTestWrapper:
     def optimized_code_chunks(self):
         # NOTE: we don't add comments to this testing functionality, so that 
         # we don't have to change tests if we update comments
-        return get_code_chunks(self.mito_widget.steps_manager.steps, optimize=True)
+        return get_code_chunks(self.mito_widget.steps_manager.steps_including_skipped, optimize=True)
 
     @property
     def curr_step_idx(self):
         return self.mito_widget.steps_manager.curr_step_idx
     
     @property
-    def steps(self):
-        return self.mito_widget.steps_manager.steps
+    def steps_including_skipped(self):
+        return self.mito_widget.steps_manager.steps_including_skipped
 
     @property
     def curr_step(self):
@@ -408,6 +408,35 @@ class MitoWidgetTestWrapper:
             }
         )
     
+
+    @check_transpiled_code_after_call
+    def one_hot_encoding(
+            self, 
+            sheet_index: int,
+            column_header: ColumnHeader,
+        ) -> bool:
+
+        column_id =self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index,
+            column_header
+        )
+
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'one_hot_encoding_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_id': column_id,
+                    
+                }
+            }
+        )
+    
 # AUTOGENERATED LINE: TEST (DO NOT DELETE)
 
     @check_transpiled_code_after_call
@@ -725,7 +754,7 @@ class MitoWidgetTestWrapper:
         )
 
     @check_transpiled_code_after_call
-    def simple_import(self, file_names: List[str]) -> bool:
+    def simple_import(self, file_names: List[str], delimeters: Optional[List[str]]=None, encodings: Optional[List[str]]=None, error_bad_lines: Optional[List[bool]]=None) -> bool:
         return self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -734,7 +763,10 @@ class MitoWidgetTestWrapper:
                 'type': 'simple_import_edit',
                 'step_id': get_new_id(),
                 'params': {
-                    'file_names': file_names
+                    'file_names': file_names,
+                    'delimeters': delimeters,
+                    'encodings': encodings,
+                    'error_bad_lines': error_bad_lines,
                 }
             }
         )
@@ -937,10 +969,12 @@ class MitoWidgetTestWrapper:
         xaxis_title: Optional[str]=None,
         xaxis_visible: bool=True,
         xaxis_title_font_color: str=DO_NOT_CHANGE_TITLE_FONT_COLOR_DEFAULT,
+        xaxis_type: Optional[str]=None,
         xaxis_rangeslider_visible: bool=True,
         yaxis_title: Optional[str]=None,
         yaxis_visible: bool=True,
         yaxis_title_font_color: str=DO_NOT_CHANGE_TITLE_FONT_COLOR_DEFAULT,
+        yaxis_type: Optional[str]=None,
         showlegend: bool=True,
         step_id: str=None,
         paper_bgcolor: str=DO_NOT_CHANGE_PAPER_BGCOLOR_DEFAULT,
@@ -974,6 +1008,7 @@ class MitoWidgetTestWrapper:
                             'title': xaxis_title,
                             'visible': xaxis_visible,
                             'title_font_color': xaxis_title_font_color,
+                            'type': xaxis_type,
                             'rangeslider': {
                                 'visible': xaxis_rangeslider_visible
                             }
@@ -982,6 +1017,7 @@ class MitoWidgetTestWrapper:
                             'title': yaxis_title,
                             'visible': yaxis_visible,
                             'title_font_color': yaxis_title_font_color,
+                            'type': yaxis_type
                         },
                         'showlegend': showlegend,
                         'paper_bgcolor': paper_bgcolor,
