@@ -1,3 +1,8 @@
+#!/usr/bin/env python
+# coding: utf-8
+
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 """
 conftest is the standard pytest testing config file, where
 we store decorators we use
@@ -12,7 +17,7 @@ from copy import deepcopy
 from mitosheet import __version__
 from mitosheet.user import is_running_test
 from mitosheet.user.db import USER_JSON_PATH, get_user_field, get_user_json_object
-from mitosheet.user.schemas import UJ_FEEDBACKS_V2, USER_JSON_DEFAULT
+from mitosheet.user.schemas import UJ_EXPERIMENT, UJ_FEEDBACKS_V2, USER_JSON_DEFAULT
 from mitosheet.user.schemas import (
     UJ_USER_JSON_VERSION, UJ_STATIC_USER_ID, UJ_USER_SALT, UJ_USER_EMAIL, 
     UJ_RECEIVED_TOURS, UJ_FEEDBACKS, UJ_MITOSHEET_CURRENT_VERSION, 
@@ -71,7 +76,8 @@ def check_user_json(
         mitosheet_last_upgraded_date=today_str,
         mitosheet_last_fifty_usages=[today_str],
         mitosheet_telemetry=True,
-        mitosheet_is_pro=False
+        mitosheet_is_pro=False,
+        mitosheet_experiment=True,
     ):
     """
     This is the main helper function that does sanity checks about the 
@@ -81,7 +87,7 @@ def check_user_json(
     """
     assert set(get_user_json_object().keys()) == set(USER_JSON_DEFAULT.keys())
 
-    assert get_user_field(UJ_USER_JSON_VERSION) == 5
+    assert get_user_field(UJ_USER_JSON_VERSION) == 6
     assert len(get_user_field(UJ_STATIC_USER_ID)) > 0
     assert len(get_user_field(UJ_USER_SALT)) > 0
     assert (get_user_field(UJ_USER_EMAIL) == user_email or (get_user_field(UJ_USER_EMAIL) == 'github@action.com' and is_running_test()))
@@ -93,4 +99,5 @@ def check_user_json(
     assert get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES) == mitosheet_last_fifty_usages
     assert get_user_field(UJ_MITOSHEET_TELEMETRY) == mitosheet_telemetry
     assert get_user_field(UJ_MITOSHEET_PRO) == mitosheet_is_pro
+    assert get_user_field(UJ_EXPERIMENT) is not None
 
